pub struct KeyboardInput { /* private fields */ }Expand description
Stores the current keyboard state
Implementations
Sourceimpl KeyboardInput
impl KeyboardInput
Sourcepub fn just_pressed(&self, key: KeyCode) -> bool
pub fn just_pressed(&self, key: KeyCode) -> bool
Returns true if the key was pressed during this frame
Sourcepub fn just_released(&self, key: KeyCode) -> bool
pub fn just_released(&self, key: KeyCode) -> bool
Returns true if the key was released during this frame